@@ -1,3 +1,4 @@
+//! Functions for working with patches in a Debian package.
 use breezyshim::branch::Branch;
 use breezyshim::delta::filter_excluded;
 use breezyshim::error::Error as BrzError;
@@ -11,6 +12,7 @@ use std::io::Write;
 use std::path::{Path, PathBuf};
 
 // TODO(jelmer): Use debmutate version
+/// Default name of the patches directory.
 pub const DEFAULT_DEBIAN_PATCHES_DIR: &str = "debian/patches";
 
 /// Find the name of the patches directory.
@@ -118,6 +120,7 @@ fn test_rules_find_patches_directory() {
     );
 }
 
+/// Find the patches directory for a package
 pub fn find_patches_directory(tree: &dyn Tree, subpath: &Path) -> Option<PathBuf> {
     let rules_path = subpath.join("debian/rules");
 
@@ -195,6 +198,7 @@ pub fn find_patch_base(tree: &WorkingTree) -> Option<RevisionId> {
 
 #[cfg(test)]
 mod find_patch_base_tests {
+    const COMMITTER: &str = "Test Suite <test@suite.example.com>";
     use breezyshim::tree::{MutableTree, WorkingTree};
     use breezyshim::RevisionId;
 
@@ -205,7 +209,12 @@ mod find_patch_base_tests {
             &breezyshim::controldir::ControlDirFormat::default(),
         )
         .unwrap();
-        let upstream_revid = tree.commit("upstream", None, None, None).unwrap();
+        let upstream_revid = tree
+            .build_commit()
+            .message("upstream")
+            .committer(COMMITTER)
+            .commit()
+            .unwrap();
         tree.mkdir(std::path::Path::new("debian")).unwrap();
         std::fs::write(
             td.path().join("debian/changelog"),
@@ -502,7 +511,7 @@ mod move_upstream_changes_to_patch_tests {
             "patch",
             "This is a description",
             None,
-            Some(chrono::NaiveDate::from_ymd(2020, 1, 1)),
+            Some(chrono::NaiveDate::from_ymd_opt(2020, 1, 1).unwrap()),
         )
         .unwrap();
 
@@ -542,6 +551,7 @@ Last-Update: 2020-01-01
     }
 }
 
+/// Read quilt patches from a directory.
 pub fn read_quilt_patches<'a>(
     tree: &'a dyn Tree,
     directory: &'a std::path::Path,
@@ -565,6 +575,7 @@ pub fn read_quilt_patches<'a>(
 
 #[cfg(test)]
 mod read_quilt_patches_tests {
+    const COMMITTER: &str = "Test Suite <test@suite.example.com>";
     use breezyshim::controldir::ControlDirFormat;
     use breezyshim::tree::MutableTree;
 
@@ -605,7 +616,11 @@ mod read_quilt_patches_tests {
             .as_slice(),
         )
         .unwrap();
-        tree.commit("add patch", None, None, None).unwrap();
+        tree.build_commit()
+            .message("add patch")
+            .committer(COMMITTER)
+            .commit()
+            .unwrap();
         let patches = super::read_quilt_patches(&tree, std::path::Path::new("debian/patches"))
             .collect::<Vec<_>>();
         assert_eq!(1, patches.len());
@@ -643,13 +658,18 @@ mod read_quilt_patches_tests {
         .unwrap();
         tree.add(&[std::path::Path::new("debian/patches/series")])
             .unwrap();
-        tree.commit("add series", None, None, None).unwrap();
+        tree.build_commit()
+            .message("add series")
+            .committer(COMMITTER)
+            .commit()
+            .unwrap();
         let patches = super::read_quilt_patches(&tree, std::path::Path::new("debian/patches"))
             .collect::<Vec<_>>();
         assert_eq!(0, patches.len());
     }
 }
 
+/// Get the upstream tree with patches applied.
 pub fn upstream_with_applied_patches(
     tree: WorkingTree,
     patches: Vec<UnifiedPatch>,
@@ -672,6 +692,7 @@ pub fn upstream_with_applied_patches(
 
 #[cfg(test)]
 mod upstream_with_applied_patches_tests {
+    const COMMITTER: &str = "Test Suite <test@suite.example.com>";
     use breezyshim::tree::{MutableTree, WorkingTree};
     use breezyshim::RevisionId;
 
@@ -684,7 +705,12 @@ mod upstream_with_applied_patches_tests {
         .unwrap();
         std::fs::write(td.path().join("afile"), b"some line\n").unwrap();
         tree.add(&[std::path::Path::new("afile")]).unwrap();
-        let upstream_revid = tree.commit("upstream", None, None, None).unwrap();
+        let upstream_revid = tree
+            .build_commit()
+            .message("upstream")
+            .committer(COMMITTER)
+            .commit()
+            .unwrap();
         tree.mkdir(std::path::Path::new("debian")).unwrap();
         std::fs::write(
             td.path().join("debian/changelog"),
@@ -790,6 +816,7 @@ pub fn tree_non_patches_changes(
 
 #[cfg(test)]
 mod tree_non_patches_changes_tests {
+    const COMMITTER: &str = "Test Suite <test@suite.example.com>";
     use breezyshim::tree::{MutableTree, WorkingTree};
     use breezyshim::RevisionId;
     fn setup() -> (tempfile::TempDir, WorkingTree, RevisionId) {
@@ -804,7 +831,12 @@ mod tree_non_patches_changes_tests {
 
         std::fs::write(td.path().join("afile"), b"some line\n").unwrap();
         local_tree.add(&[std::path::Path::new("afile")]).unwrap();
-        let upstream_revid = local_tree.commit("upstream", None, None, None).unwrap();
+        let upstream_revid = local_tree
+            .build_commit()
+            .message("upstream")
+            .committer(COMMITTER)
+            .commit()
+            .unwrap();
 
         local_tree.mkdir(std::path::Path::new("debian")).unwrap();
         std::fs::write(
